# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.change_complex_relation_type_request import ChangeComplexRelationTypeRequest  # noqa: E501
from collibra_core.rest import ApiException

class TestChangeComplexRelationTypeRequest(unittest.TestCase):
    """ChangeComplexRelationTypeRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ChangeComplexRelationTypeRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.change_complex_relation_type_request.ChangeComplexRelationTypeRequest()  # noqa: E501
        if include_optional :
            return ChangeComplexRelationTypeRequest(
                name = '0', 
                description = '0', 
                color = 'a', 
                symbol_type = 'NONE', 
                icon_code = '0', 
                acronym_code = 'a', 
                attribute_types = [
                    collibra_core.models.complex_relation_attribute_type_request.ComplexRelationAttributeTypeRequest(
                        min = 0, 
                        max = 2, 
                        attribute_type_id = '0', 
                        id = '0', )
                    ], 
                leg_types = [
                    collibra_core.models.complex_relation_leg_type_request.ComplexRelationLegTypeRequest(
                        min = 1, 
                        max = 3, 
                        role = '0', 
                        co_role = '0', 
                        asset_type_id = '0', 
                        id = '0', 
                        relation_type_id = '0', )
                    ]
            )
        else :
            return ChangeComplexRelationTypeRequest(
        )

    def testChangeComplexRelationTypeRequest(self):
        """Test ChangeComplexRelationTypeRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
