# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.tags_api import TagsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.tags_api.TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_tag(self):
        """Test case for change_tag

        Change tag.  # noqa: E501
        """
        pass

    def test_exists(self):
        """Test case for exists

        Check tag name.  # noqa: E501
        """
        pass

    def test_find_tags(self):
        """Test case for find_tags

        Find tags.  # noqa: E501
        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        Get tag.  # noqa: E501
        """
        pass

    def test_get_tags_by_asset_id(self):
        """Test case for get_tags_by_asset_id

        Get asset tags.  # noqa: E501
        """
        pass

    def test_merge_tags(self):
        """Test case for merge_tags

        Merge tags.  # noqa: E501
        """
        pass

    def test_remove_tag(self):
        """Test case for remove_tag

        Remove tag.  # noqa: E501
        """
        pass

    def test_remove_tags(self):
        """Test case for remove_tags

        Remove tags.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
