# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.output_module_api import OutputModuleApi  # noqa: E501
from collibra_core.rest import ApiException


class TestOutputModuleApi(unittest.TestCase):
    """OutputModuleApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.output_module_api.OutputModuleApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_export_csv(self):
        """Test case for export_csv

        Exports results in CSV format, returns the results immediately.  # noqa: E501
        """
        pass

    def test_export_csv_in_job(self):
        """Test case for export_csv_in_job

        Exports results in CSV format, returns JSON representation of the async Job.  # noqa: E501
        """
        pass

    def test_export_csv_to_file(self):
        """Test case for export_csv_to_file

        Exports results in CSV format, returns information about created file.  # noqa: E501
        """
        pass

    def test_export_excel_in_job(self):
        """Test case for export_excel_in_job

        Exports results in Excel format, returns JSON representation of the async Job.  # noqa: E501
        """
        pass

    def test_export_excel_to_file(self):
        """Test case for export_excel_to_file

        Exports results in Excel format, returns information about created file.  # noqa: E501
        """
        pass

    def test_export_json(self):
        """Test case for export_json

        Exports results in JSON format, returns the results immediately.  # noqa: E501
        """
        pass

    def test_export_json_in_job(self):
        """Test case for export_json_in_job

        Exports results in JSON format, returns JSON representation of the async Job.  # noqa: E501
        """
        pass

    def test_export_json_to_file(self):
        """Test case for export_json_to_file

        Exports results in JSON format, returns information about created file.  # noqa: E501
        """
        pass

    def test_export_xml(self):
        """Test case for export_xml

        Exports results in XML format, returns the results immediately.  # noqa: E501
        """
        pass

    def test_export_xml_in_job(self):
        """Test case for export_xml_in_job

        Exports results in XML format, returns JSON representation of the async Job.  # noqa: E501
        """
        pass

    def test_export_xml_to_file(self):
        """Test case for export_xml_to_file

        Exports results in XML format, returns information about created file.  # noqa: E501
        """
        pass

    def test_get_table_view_config_by_view_id(self):
        """Test case for get_table_view_config_by_view_id

        Returns TableViewConfig based on id of given View and its Location.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
