# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.assignments_api import AssignmentsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestAssignmentsApi(unittest.TestCase):
    """AssignmentsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.assignments_api.AssignmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_assignment(self):
        """Test case for add_assignment

        Adds a new Assignment.  # noqa: E501
        """
        pass

    def test_change_assignment(self):
        """Test case for change_assignment

        Changes the assignment with the information that is provided in the request.  # noqa: E501
        """
        pass

    def test_find_assignments_for_resource(self):
        """Test case for find_assignments_for_resource

        Find the assignments where a given resource is assigned.  # noqa: E501
        """
        pass

    def test_get_assignments_for_asset(self):
        """Test case for get_assignments_for_asset

        Returns the Assignment identified by the given Asset.  # noqa: E501
        """
        pass

    def test_get_assignments_for_asset_type(self):
        """Test case for get_assignments_for_asset_type

        Returns Assignments for given asset type id.  # noqa: E501
        """
        pass

    def test_get_available_asset_types_for_domain(self):
        """Test case for get_available_asset_types_for_domain

        Returns available asset types for domain identified by given id.  # noqa: E501
        """
        pass

    def test_get_available_attribute_types_for_asset(self):
        """Test case for get_available_attribute_types_for_asset

        Returns available attribute types for asset identified by given id.  # noqa: E501
        """
        pass

    def test_get_available_complex_relation_types_for_asset(self):
        """Test case for get_available_complex_relation_types_for_asset

        Returns the available ComplexRelationTypes for the Asset identified by the given id.  # noqa: E501
        """
        pass

    def test_get_available_relation_types_for_asset(self):
        """Test case for get_available_relation_types_for_asset

        Returns the available RelationTypes for the Asset identified by the given id.  # noqa: E501
        """
        pass

    def test_remove_assignment(self):
        """Test case for remove_assignment

        Removes the Assignment identified by the given id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
