# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.complex_relations_api import ComplexRelationsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestComplexRelationsApi(unittest.TestCase):
    """ComplexRelationsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.complex_relations_api.ComplexRelationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_complex_relation(self):
        """Test case for add_complex_relation

        Adds new complex relation.  # noqa: E501
        """
        pass

    def test_change_complex_relation(self):
        """Test case for change_complex_relation

        Change the complex relation with the information that is present in the request.  # noqa: E501
        """
        pass

    def test_export_to_csv(self):
        """Test case for export_to_csv

        Export complex relations of the given type to CSV.  # noqa: E501
        """
        pass

    def test_export_to_csv_as_string(self):
        """Test case for export_to_csv_as_string

        Export all complex relations of the given type to CSV as a String.  # noqa: E501
        """
        pass

    def test_export_to_csv_without_job(self):
        """Test case for export_to_csv_without_job

        Export all complex relations of the given type to a CSV file.  # noqa: E501
        """
        pass

    def test_export_to_excel(self):
        """Test case for export_to_excel

        Export complex relations of the given type to Excel.  # noqa: E501
        """
        pass

    def test_export_to_excel_without_job(self):
        """Test case for export_to_excel_without_job

        Export all complex relations of the given type to an Excel file.  # noqa: E501
        """
        pass

    def test_find_complex_relations(self):
        """Test case for find_complex_relations

        Returns complex relations matching the given search criteria.  # noqa: E501
        """
        pass

    def test_get_complex_relation(self):
        """Test case for get_complex_relation

        Returns a ComplexRelation identified by given id.  # noqa: E501
        """
        pass

    def test_remove_complex_relation(self):
        """Test case for remove_complex_relation

        Removes complex relation identified by given id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
