# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.workflow_instances_api import WorkflowInstancesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestWorkflowInstancesApi(unittest.TestCase):
    """WorkflowInstancesApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.workflow_instances_api.WorkflowInstancesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_workflow_instances(self):
        """Test case for cancel_workflow_instances

        Cancel workflow instance.  # noqa: E501
        """
        pass

    def test_find_workflow_instances(self):
        """Test case for find_workflow_instances

        Find workflow instances.  # noqa: E501
        """
        pass

    def test_get_workflow_instance_diagram(self):
        """Test case for get_workflow_instance_diagram

        Returns the file representing the diagram of workflow instance identified by the given ID.  # noqa: E501
        """
        pass

    def test_message_event_received(self):
        """Test case for message_event_received

        Pass message event to workflow engine.  # noqa: E501
        """
        pass

    def test_start_workflow_instances(self):
        """Test case for start_workflow_instances

        Start workflow instances.  # noqa: E501
        """
        pass

    def test_start_workflow_instances_in_job(self):
        """Test case for start_workflow_instances_in_job

        Start workflow instances.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
