# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.communities_api import CommunitiesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestCommunitiesApi(unittest.TestCase):
    """CommunitiesApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.communities_api.CommunitiesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_communities(self):
        """Test case for add_communities

        Add multiple communities  # noqa: E501
        """
        pass

    def test_add_community(self):
        """Test case for add_community

        Add community  # noqa: E501
        """
        pass

    def test_change_communities(self):
        """Test case for change_communities

        Change multiple communities  # noqa: E501
        """
        pass

    def test_change_community(self):
        """Test case for change_community

        Change community  # noqa: E501
        """
        pass

    def test_change_to_root_community(self):
        """Test case for change_to_root_community

        Change to root community  # noqa: E501
        """
        pass

    def test_find_communities(self):
        """Test case for find_communities

        Find communities  # noqa: E501
        """
        pass

    def test_get_community(self):
        """Test case for get_community

        Get community  # noqa: E501
        """
        pass

    def test_get_community_breadcrumb(self):
        """Test case for get_community_breadcrumb

        Get community breadcrumb  # noqa: E501
        """
        pass

    def test_remove_communities(self):
        """Test case for remove_communities

        Remove multiple communities  # noqa: E501
        """
        pass

    def test_remove_communities_in_job(self):
        """Test case for remove_communities_in_job

        Remove multiple communities asynchronously  # noqa: E501
        """
        pass

    def test_remove_community(self):
        """Test case for remove_community

        Remove community  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
