# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class AssetAssignmentRuleImpl(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'asset_type': 'NamedResourceReferenceImpl',
        'domain': 'NamedResourceReferenceImpl',
        'community': 'NamedResourceReferenceImpl',
        'status': 'NamedResourceReferenceImpl'
    }

    attribute_map = {
        'id': 'id',
        'asset_type': 'assetType',
        'domain': 'domain',
        'community': 'community',
        'status': 'status'
    }

    def __init__(self, id=None, asset_type=None, domain=None, community=None, status=None, local_vars_configuration=None):  # noqa: E501
        """AssetAssignmentRuleImpl - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._asset_type = None
        self._domain = None
        self._community = None
        self._status = None
        self.discriminator = None

        self.id = id
        if asset_type is not None:
            self.asset_type = asset_type
        if domain is not None:
            self.domain = domain
        if community is not None:
            self.community = community
        if status is not None:
            self.status = status

    @property
    def id(self):
        """Gets the id of this AssetAssignmentRuleImpl.  # noqa: E501

        The id of the represented object (entity).  # noqa: E501

        :return: The id of this AssetAssignmentRuleImpl.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AssetAssignmentRuleImpl.

        The id of the represented object (entity).  # noqa: E501

        :param id: The id of this AssetAssignmentRuleImpl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def asset_type(self):
        """Gets the asset_type of this AssetAssignmentRuleImpl.  # noqa: E501


        :return: The asset_type of this AssetAssignmentRuleImpl.  # noqa: E501
        :rtype: NamedResourceReferenceImpl
        """
        return self._asset_type

    @asset_type.setter
    def asset_type(self, asset_type):
        """Sets the asset_type of this AssetAssignmentRuleImpl.


        :param asset_type: The asset_type of this AssetAssignmentRuleImpl.  # noqa: E501
        :type: NamedResourceReferenceImpl
        """

        self._asset_type = asset_type

    @property
    def domain(self):
        """Gets the domain of this AssetAssignmentRuleImpl.  # noqa: E501


        :return: The domain of this AssetAssignmentRuleImpl.  # noqa: E501
        :rtype: NamedResourceReferenceImpl
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this AssetAssignmentRuleImpl.


        :param domain: The domain of this AssetAssignmentRuleImpl.  # noqa: E501
        :type: NamedResourceReferenceImpl
        """

        self._domain = domain

    @property
    def community(self):
        """Gets the community of this AssetAssignmentRuleImpl.  # noqa: E501


        :return: The community of this AssetAssignmentRuleImpl.  # noqa: E501
        :rtype: NamedResourceReferenceImpl
        """
        return self._community

    @community.setter
    def community(self, community):
        """Sets the community of this AssetAssignmentRuleImpl.


        :param community: The community of this AssetAssignmentRuleImpl.  # noqa: E501
        :type: NamedResourceReferenceImpl
        """

        self._community = community

    @property
    def status(self):
        """Gets the status of this AssetAssignmentRuleImpl.  # noqa: E501


        :return: The status of this AssetAssignmentRuleImpl.  # noqa: E501
        :rtype: NamedResourceReferenceImpl
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AssetAssignmentRuleImpl.


        :param status: The status of this AssetAssignmentRuleImpl.  # noqa: E501
        :type: NamedResourceReferenceImpl
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetAssignmentRuleImpl):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssetAssignmentRuleImpl):
            return True

        return self.to_dict() != other.to_dict()
