# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.statuses_api import StatusesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestStatusesApi(unittest.TestCase):
    """StatusesApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.statuses_api.StatusesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_status(self):
        """Test case for add_status

        Adds a new Status.  # noqa: E501
        """
        pass

    def test_add_statuses(self):
        """Test case for add_statuses

        Adds multiple statuses in one go.  # noqa: E501
        """
        pass

    def test_change_status(self):
        """Test case for change_status

        Changes the status with the information that is present in the request.  # noqa: E501
        """
        pass

    def test_change_statuses(self):
        """Test case for change_statuses

        Changes multiple statuses in one go.  # noqa: E501
        """
        pass

    def test_find_statuses(self):
        """Test case for find_statuses

        Returns statuses matching the given search criteria.  # noqa: E501
        """
        pass

    def test_get_status(self):
        """Test case for get_status

        Returns the Status identified by the given id.  # noqa: E501
        """
        pass

    def test_get_status_by_name(self):
        """Test case for get_status_by_name

        Returns the Status identified by the given name.  # noqa: E501
        """
        pass

    def test_remove_status(self):
        """Test case for remove_status

        Removes the Status identified by the given id.  # noqa: E501
        """
        pass

    def test_remove_statuses(self):
        """Test case for remove_statuses

        Removes multiple statuses.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
