# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.add_data_quality_rule_request import AddDataQualityRuleRequest  # noqa: E501
from collibra_core.rest import ApiException

class TestAddDataQualityRuleRequest(unittest.TestCase):
    """AddDataQualityRuleRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AddDataQualityRuleRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.add_data_quality_rule_request.AddDataQualityRuleRequest()  # noqa: E501
        if include_optional :
            return AddDataQualityRuleRequest(
                id = '0', 
                name = '0', 
                description = '0', 
                categorization_relation_type_id = '0', 
                data_quality_metrics = [
                    collibra_core.models.data_quality_metric_request.DataQualityMetricRequest(
                        count_operation = 'Sum', 
                        attribute_type_id = '0', )
                    ], 
                relation_trace_entries = [
                    collibra_core.models.relation_trace_entry_request.RelationTraceEntryRequest(
                        role_direction = True, 
                        relation_type_id = '0', )
                    ]
            )
        else :
            return AddDataQualityRuleRequest(
                name = '0',
                categorization_relation_type_id = '0',
                relation_trace_entries = [
                    collibra_core.models.relation_trace_entry_request.RelationTraceEntryRequest(
                        role_direction = True, 
                        relation_type_id = '0', )
                    ],
        )

    def testAddDataQualityRuleRequest(self):
        """Test AddDataQualityRuleRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
