# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.workflow_definitions_api import WorkflowDefinitionsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestWorkflowDefinitionsApi(unittest.TestCase):
    """WorkflowDefinitionsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.workflow_definitions_api.WorkflowDefinitionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_asset_type_assignment_rule(self):
        """Test case for add_asset_type_assignment_rule

        Add asset type assignment rule.  # noqa: E501
        """
        pass

    def test_add_domain_type_assignment_rule(self):
        """Test case for add_domain_type_assignment_rule

        Add domain type assignment rule.  # noqa: E501
        """
        pass

    def test_change_asset_type_assignment_rule(self):
        """Test case for change_asset_type_assignment_rule

        Change asset type assignment rule.  # noqa: E501
        """
        pass

    def test_change_domain_type_assignment_rule(self):
        """Test case for change_domain_type_assignment_rule

        Change domain type assignment rule.  # noqa: E501
        """
        pass

    def test_change_workflow_definition(self):
        """Test case for change_workflow_definition

        Change workflow definition.  # noqa: E501
        """
        pass

    def test_deploy_workflow_definition(self):
        """Test case for deploy_workflow_definition

        Deploy workflow definition.  # noqa: E501
        """
        pass

    def test_find_workflow_definitions(self):
        """Test case for find_workflow_definitions

        Find workflow definitions.  # noqa: E501
        """
        pass

    def test_get_configuration_start_form_data(self):
        """Test case for get_configuration_start_form_data

        Get configuration start form data.  # noqa: E501
        """
        pass

    def test_get_possible_start_events(self):
        """Test case for get_possible_start_events

        Get all possible workflow start events  # noqa: E501
        """
        pass

    def test_get_start_form_data(self):
        """Test case for get_start_form_data

        Get start form data.  # noqa: E501
        """
        pass

    def test_get_workflow_definition(self):
        """Test case for get_workflow_definition

        Get workflow definition.  # noqa: E501
        """
        pass

    def test_get_workflow_definition_by_process_id(self):
        """Test case for get_workflow_definition_by_process_id

        Get workflow definition.  # noqa: E501
        """
        pass

    def test_get_workflow_definition_diagram(self):
        """Test case for get_workflow_definition_diagram

        Get process diagram.  # noqa: E501
        """
        pass

    def test_get_workflow_definition_xml(self):
        """Test case for get_workflow_definition_xml

        Get XML of workflow definition.  # noqa: E501
        """
        pass

    def test_remove_assignment_rule(self):
        """Test case for remove_assignment_rule

        Remove assignment rule.  # noqa: E501
        """
        pass

    def test_remove_workflow_definition(self):
        """Test case for remove_workflow_definition

        Remove workflow definition.  # noqa: E501
        """
        pass

    def test_remove_workflow_definitions_in_job(self):
        """Test case for remove_workflow_definitions_in_job

        Remove multiple workflow definitions.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
