# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.domains_api import DomainsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestDomainsApi(unittest.TestCase):
    """DomainsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.domains_api.DomainsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_domain(self):
        """Test case for add_domain

        Add domain  # noqa: E501
        """
        pass

    def test_add_domains(self):
        """Test case for add_domains

        Add multpile domains  # noqa: E501
        """
        pass

    def test_change_domain(self):
        """Test case for change_domain

        Change domain  # noqa: E501
        """
        pass

    def test_change_domains(self):
        """Test case for change_domains

        Change multiple domains  # noqa: E501
        """
        pass

    def test_find_domains(self):
        """Test case for find_domains

        Search domains  # noqa: E501
        """
        pass

    def test_get_domain(self):
        """Test case for get_domain

        Get domain  # noqa: E501
        """
        pass

    def test_get_domain_breadcrumb(self):
        """Test case for get_domain_breadcrumb

        Get domain breadcrumb  # noqa: E501
        """
        pass

    def test_remove_domain(self):
        """Test case for remove_domain

        Remove domain  # noqa: E501
        """
        pass

    def test_remove_domains(self):
        """Test case for remove_domains

        Remove multiple domains  # noqa: E501
        """
        pass

    def test_remove_domains_in_job(self):
        """Test case for remove_domains_in_job

        Remove multiple domains asynchronously  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
