# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.job_paged_response import JobPagedResponse  # noqa: E501
from collibra_core.rest import ApiException

class TestJobPagedResponse(unittest.TestCase):
    """JobPagedResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test JobPagedResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.job_paged_response.JobPagedResponse()  # noqa: E501
        if include_optional :
            return JobPagedResponse(
                total = 1000, 
                offset = 10, 
                limit = 100, 
                results = [
                    collibra_core.models.job.Job(
                        id = '0', 
                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                        created_on = 1475503010320, 
                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                        last_modified_on = 1476703764163, 
                        system = True, 
                        resource_type = 'View', 
                        name = 'Test name', 
                        type = 'IMPORT', 
                        user_id = '0', 
                        visibility = 56, 
                        progress_percentage = 50, 
                        cancelable = True, 
                        start_date = 1488016800, 
                        end_date = 1488021800, 
                        state = 'COMPLETED', 
                        result = 'SUCCESS', 
                        message = 'Import finished in 12s.', )
                    ]
            )
        else :
            return JobPagedResponse(
        )

    def testJobPagedResponse(self):
        """Test JobPagedResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
