# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.assets_api import AssetsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestAssetsApi(unittest.TestCase):
    """AssetsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.assets_api.AssetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_asset(self):
        """Test case for add_asset

        Add asset  # noqa: E501
        """
        pass

    def test_add_assets(self):
        """Test case for add_assets

        Add multiple assets  # noqa: E501
        """
        pass

    def test_add_tags_to_asset(self):
        """Test case for add_tags_to_asset

        Add tags  # noqa: E501
        """
        pass

    def test_change_asset(self):
        """Test case for change_asset

        Change asset  # noqa: E501
        """
        pass

    def test_change_assets(self):
        """Test case for change_assets

        Change multiple assets  # noqa: E501
        """
        pass

    def test_find_assets(self):
        """Test case for find_assets

        Find assets  # noqa: E501
        """
        pass

    def test_get_asset(self):
        """Test case for get_asset

        Get asset  # noqa: E501
        """
        pass

    def test_get_asset_breadcrumb(self):
        """Test case for get_asset_breadcrumb

        Get asset breadcrumb  # noqa: E501
        """
        pass

    def test_get_asset_tags(self):
        """Test case for get_asset_tags

        Get asset tags  # noqa: E501
        """
        pass

    def test_remove_asset(self):
        """Test case for remove_asset

        Remove asset  # noqa: E501
        """
        pass

    def test_remove_assets(self):
        """Test case for remove_assets

        Remove assets  # noqa: E501
        """
        pass

    def test_remove_tags_from_asset(self):
        """Test case for remove_tags_from_asset

        Remove tags  # noqa: E501
        """
        pass

    def test_set_asset_attributes(self):
        """Test case for set_asset_attributes

        Set asset attributes  # noqa: E501
        """
        pass

    def test_set_asset_relations(self):
        """Test case for set_asset_relations

        Set asset relations  # noqa: E501
        """
        pass

    def test_set_asset_responsibilities(self):
        """Test case for set_asset_responsibilities

        Set asset responsibilities  # noqa: E501
        """
        pass

    def test_set_tags_for_asset(self):
        """Test case for set_tags_for_asset

        Set asset tags  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
