# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.workflow_tasks_api import WorkflowTasksApi  # noqa: E501
from collibra_core.rest import ApiException


class TestWorkflowTasksApi(unittest.TestCase):
    """WorkflowTasksApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.workflow_tasks_api.WorkflowTasksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_workflow_task(self):
        """Test case for cancel_workflow_task

        Cancel workflow task.  # noqa: E501
        """
        pass

    def test_complete_workflow_tasks(self):
        """Test case for complete_workflow_tasks

        Complete workflow tasks.  # noqa: E501
        """
        pass

    def test_find_workflow_tasks(self):
        """Test case for find_workflow_tasks

        Find workflow tasks.  # noqa: E501
        """
        pass

    def test_get_task_form_data(self):
        """Test case for get_task_form_data

        Get task form data.  # noqa: E501
        """
        pass

    def test_get_workflow_task(self):
        """Test case for get_workflow_task

        Get workflow task.  # noqa: E501
        """
        pass

    def test_reassign_task(self):
        """Test case for reassign_task

        Reassign task.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
