# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.relations_api import RelationsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestRelationsApi(unittest.TestCase):
    """RelationsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.relations_api.RelationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_relation(self):
        """Test case for add_relation

        Adds a new relation.  # noqa: E501
        """
        pass

    def test_add_relations(self):
        """Test case for add_relations

        Adds multiple relations in one go.  # noqa: E501
        """
        pass

    def test_change_relation(self):
        """Test case for change_relation

        Changes the relation with the information that is present in the request.  # noqa: E501
        """
        pass

    def test_change_relations(self):
        """Test case for change_relations

        Changes multiple relations.  # noqa: E501
        """
        pass

    def test_find_relations(self):
        """Test case for find_relations

        Returns relations matching the given search criteria.  # noqa: E501
        """
        pass

    def test_get_relation(self):
        """Test case for get_relation

        Returns a relation identified by given id.  # noqa: E501
        """
        pass

    def test_remove_relation(self):
        """Test case for remove_relation

        Removes a relation identified by given id.  # noqa: E501
        """
        pass

    def test_remove_relations(self):
        """Test case for remove_relations

        Removes multiple relations.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
