# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.paged_response_workflow_definition import PagedResponseWorkflowDefinition  # noqa: E501
from collibra_core.rest import ApiException

class TestPagedResponseWorkflowDefinition(unittest.TestCase):
    """PagedResponseWorkflowDefinition unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PagedResponseWorkflowDefinition
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.paged_response_workflow_definition.PagedResponseWorkflowDefinition()  # noqa: E501
        if include_optional :
            return PagedResponseWorkflowDefinition(
                total = 1000, 
                offset = 10, 
                limit = 100, 
                results = [
                    collibra_core.models.workflow_definition_impl.WorkflowDefinitionImpl(
                        id = '0', 
                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                        created_on = 1475503010320, 
                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                        last_modified_on = 1476703764163, 
                        system = True, 
                        resource_type = 'View', 
                        name = 'Test name', 
                        description = 'Sample descripion of the resource.', 
                        process_id = '0', 
                        start_label = '0', 
                        form_required = True, 
                        start_form_key_available = True, 
                        start_form_json_model_available = True, 
                        enabled = True, 
                        domain_assignment_rules = [
                            collibra_core.models.asset_assignment_rule_impl.AssetAssignmentRuleImpl(
                                id = '0', 
                                asset_type = collibra_core.models.named_resource_reference_impl.NamedResourceReferenceImpl(
                                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                                    resource_type = 'Community', 
                                    name = '0', ), 
                                domain = collibra_core.models.named_resource_reference_impl.NamedResourceReferenceImpl(
                                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                                    resource_type = 'Community', 
                                    name = '0', ), 
                                community = collibra_core.models.named_resource_reference_impl.NamedResourceReferenceImpl(
                                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                                    resource_type = 'Community', 
                                    name = '0', ), 
                                status = collibra_core.models.named_resource_reference_impl.NamedResourceReferenceImpl(
                                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                                    resource_type = 'Community', 
                                    name = '0', ), )
                            ], 
                        asset_assignment_rules = [
                            collibra_core.models.asset_assignment_rule_impl.AssetAssignmentRuleImpl(
                                id = '0', )
                            ], 
                        business_item_resource_type = 'ASSET', 
                        exclusivity = 'RESOURCE_EXCLUSIVITY', 
                        guest_user_accessible = True, 
                        registered_user_accessible = True, 
                        candidate_user_check_enabled = True, 
                        global_create = True, 
                        start_events = [
                            'ASSET_ADDED'
                            ], 
                        configuration_variables = {
                            'key' : '0'
                            }, 
                        start_roles = [
                            collibra_core.models.role_impl.RoleImpl(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                name = 'Test name', 
                                description = 'Sample descripion of the resource.', 
                                permissions = [
                                    'EDGE'
                                    ], 
                                global = True, )
                            ], 
                        stop_roles = [
                            collibra_core.models.role_impl.RoleImpl(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                name = 'Test name', 
                                description = 'Sample descripion of the resource.', 
                                global = True, )
                            ], 
                        reassign_roles = [
                            collibra_core.models.role_impl.RoleImpl(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                name = 'Test name', 
                                description = 'Sample descripion of the resource.', 
                                global = True, )
                            ], )
                    ]
            )
        else :
            return PagedResponseWorkflowDefinition(
        )

    def testPagedResponseWorkflowDefinition(self):
        """Test PagedResponseWorkflowDefinition"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
